pub struct Command {
pub command: String,
pub args: Vec<RedisValue>,
pub timestamp: f64,
pub db: u8,
pub client: String,
}Available on crate feature
monitor only.Expand description
Fields
command: StringThe command run by the server.
args: Vec<RedisValue>Arguments passed to the command.
timestamp: f64When the command was run on the server.
db: u8The database against which the command was run.
client: StringThe host and port of the client that ran the command, or lua when run from a script.